package com.vendor.platform.ui.internal;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.platform.core.IToolManager;
import com.vendor.platform.core.PlatformCoreActivator;
import com.vendor.platform.core.ToolDescriptor;
import com.vendor.platform.ui.Messages;
import com.vendor.platform.ui.WelcomeView;
import com.vendor.platform.ui.internal.BundleUtils;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IConfigurationElement;
import org.eclipse.core.runtime.IExtension;
import org.eclipse.core.runtime.IExtensionPoint;
import org.eclipse.core.runtime.IExtensionRegistry;
import org.eclipse.core.runtime.Platform;
import org.eclipse.equinox.p2.metadata.IInstallableUnit;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.swt.widgets.Display;
import org.eclipse.ui.IPerspectiveDescriptor;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.WorkbenchException;
import org.eclipse.ui.internal.Workbench;
import org.eclipse.ui.internal.registry.PerspectiveRegistry;

public class PerspectiveUtil {
  public static final String PERSPECTIVE_SEP = "@";
  
  public static boolean activateToolsByHand = false;
  
  public static synchronized IWorkbenchPage openPerspective(String perspectiveId) throws ExecutionException {
    IWorkbench workbench = PlatformUI.getWorkbench();
    IWorkbenchWindow activeWorkbenchWindow = workbench.getActiveWorkbenchWindow();
    if (activeWorkbenchWindow == null) {
      IWorkbenchWindow[] workbenchWindows = workbench.getWorkbenchWindows();
      if (workbenchWindows != null && workbenchWindows.length > 0)
        activeWorkbenchWindow = workbenchWindows[0]; 
    } 
    if (activeWorkbenchWindow == null)
      return null; 
    IWorkbenchPage activePage = activeWorkbenchWindow.getActivePage();
    IPerspectiveDescriptor desc = activeWorkbenchWindow.getWorkbench().getPerspectiveRegistry().findPerspectiveWithId(perspectiveId);
    if (desc == null)
      throw new ExecutionException("Perspective " + perspectiveId + " cannot be found."); 
    try {
      if (activePage != null) {
        activePage.setPerspective(desc);
      } else {
        IAdaptable input = ((Workbench)workbench).getDefaultPageInput();
        activePage = activeWorkbenchWindow.openPage(perspectiveId, input);
      } 
    } catch (WorkbenchException e) {
      throw new ExecutionException("Perspective could not be opened.", e);
    } 
    return activePage;
  }
  
  public static void closeAllPerpectives() {
    IWorkbench workbench = PlatformUI.getWorkbench();
    IWorkbenchWindow activeWorkbenchWindow = workbench.getActiveWorkbenchWindow();
    IWorkbenchPage activePage = activeWorkbenchWindow.getActivePage();
    if (activePage == null)
      return; 
    activePage.closeAllPerspectives(true, false);
  }
  
  public static synchronized void closePerpective(String perspectiveId) {
    IWorkbench workbench = PlatformUI.getWorkbench();
    IWorkbenchWindow activeWorkbenchWindow = workbench.getActiveWorkbenchWindow();
    if (activeWorkbenchWindow != null) {
      IWorkbenchPage activePage = activeWorkbenchWindow.getActivePage();
      if (activePage != null) {
        IPerspectiveDescriptor desc = activeWorkbenchWindow.getWorkbench().getPerspectiveRegistry().findPerspectiveWithId(perspectiveId);
        if (desc == null)
          return; 
        activePage.closePerspective(desc, true, false);
      } 
    } 
  }
  
  public static void revertPerspective() {
    IWorkbench workbench = PlatformUI.getWorkbench();
    IWorkbenchWindow window = workbench.getActiveWorkbenchWindow();
    IWorkbenchPage activePage = window.getActivePage();
    IPerspectiveDescriptor desc = activePage.getPerspective();
    PerspectiveRegistry reg = (PerspectiveRegistry)PlatformUI.getWorkbench().getPerspectiveRegistry();
    reg.revertPerspective(desc);
    activePage.resetPerspective();
  }
  
  public static IPerspectiveDescriptor findFirstPerspectiveShortcut() {
    IWorkbench workbench = PlatformUI.getWorkbench();
    IWorkbenchWindow window = workbench.getActiveWorkbenchWindow();
    IWorkbenchPage page = window.getActivePage();
    IPerspectiveDescriptor[] descs = page.getOpenPerspectives();
    if (descs == null || descs.length < 1)
      return null; 
    return descs[0];
  }
  
  public static synchronized void addPerspectiveShortcutForWelcome(List<String> ids) {}
  
  public static synchronized void removePerspectiveShortcut(ToolDescriptor tool) {}
  
  public static synchronized void removePerspectiveShortcut(String id) {}
  
  public static synchronized void removePerspectiveShortcuts(List<ToolDescriptor> installTools, Map<String, IExtension> reg) {}
  
  public static Map<String, IExtension> loadPerspectiveRegistry() {
    Map<String, IExtension> pluginExtensions = new HashMap<>();
    IExtension[] extensions = getExtensions("org.eclipse.ui.perspectives");
    if (extensions != null)
      for (IExtension e : extensions) {
        String pluginId = e.getContributor().getName();
        pluginExtensions.put(pluginId, e);
      }  
    return pluginExtensions;
  }
  
  public static IExtension[] getExtensions(String id) {
    IExtensionRegistry registry = Platform.getExtensionRegistry();
    IExtensionPoint point = registry.getExtensionPoint(id);
    if (point == null)
      return null; 
    IExtension[] extensions = point.getExtensions();
    return extensions;
  }
  
  public static List<String> finPerspectiveDeclareIds(IExtension e) {
    List<String> ids = new ArrayList<>();
    IConfigurationElement[] elements = e.getConfigurationElements();
    for (int i = 0; i < elements.length; i++) {
      if (elements[i].getName().equals("perspective")) {
        String id = elements[i].getAttribute("id");
        ids.add(id);
      } 
    } 
    return ids;
  }
  
  public static List<String> finPerspectiveDeclareIds(ToolDescriptor tool, Map<String, IExtension> reg) {
    List<String> ids = new ArrayList<>();
    String[] plugins = tool.getPluginIds();
    for (String id : plugins) {
      IExtension ext = reg.get(id);
      if (ext != null) {
        List<String> list = finPerspectiveDeclareIds(ext);
        if (!list.isEmpty())
          ids.addAll(list); 
      } 
    } 
    return ids;
  }
  
  public static void openBundlePerspective(ToolDescriptor tool) {
    Map<String, IExtension> reg = loadPerspectiveRegistry();
    List<String> ids = finPerspectiveDeclareIds(tool, reg);
    if (ids.size() == 0)
      return; 
    String id = ids.get(0);
    try {
      openPerspective(id);
    } catch (Exception e) {
      MessageDialog.openError(Display.getDefault().getActiveShell(), Messages.PerspectiveUtil_1, Messages.PerspectiveUtil_2 + Messages.PerspectiveUtil_2);
    } 
  }
  
  private static String getDefaultPerspective() {
    Map<String, IExtension> reg = loadPerspectiveRegistry();
    IToolManager m = PlatformCoreActivator.getDefault().getToolManager();
    List<IInstallableUnit> installIUs = m.getInstalledToolIUs();
    List<ToolDescriptor> installTools = m.collectFeatureTools(installIUs);
    IWorkbench workbench = PlatformUI.getWorkbench();
    IWorkbenchWindow activeWorkbenchWindow = workbench.getActiveWorkbenchWindow();
    if (activeWorkbenchWindow == null) {
      IWorkbenchWindow[] workbenchWindows = workbench.getWorkbenchWindows();
      if (workbenchWindows != null && workbenchWindows.length > 0)
        activeWorkbenchWindow = workbenchWindows[0]; 
    } 
    if (activeWorkbenchWindow == null)
      return null; 
    List<String> list = new ArrayList<>();
    IWorkbenchPage activePage = activeWorkbenchWindow.getActivePage();
    IPerspectiveDescriptor perspective = activePage.getPerspective();
    String currentPerspectiveId = null;
    if (perspective != null)
      currentPerspectiveId = perspective.getId(); 
    for (ToolDescriptor t : installTools) {
      if (!BundleUtils.isToolEnabled(t))
        continue; 
      List<String> ids = finPerspectiveDeclareIds(t, reg);
      if (ids.size() == 0)
        continue; 
      String id = ids.get(0);
      IPerspectiveDescriptor desc = null;
      try {
        desc = activeWorkbenchWindow.getWorkbench().getPerspectiveRegistry().findPerspectiveWithId(id);
      } catch (Exception exception) {}
      if (desc != null) {
        if (currentPerspectiveId != null && currentPerspectiveId
          .equals(id))
          return id; 
        list.add(id);
      } 
    } 
    if (list.size() > 0)
      return list.get(0); 
    return null;
  }
  
  public static void openPerspectiveOnTheRight(String id) throws ExecutionException {
    openPerspective(id);
  }
  
  public static synchronized void addPerspectiveToWelcomeView(Map<String, Integer> needUpdatePerspectiveIDS) {
    WelcomeView.READED_BUNDLES.putAll(needUpdatePerspectiveIDS);
    WelcomeView wv = WelcomeView.getInstance();
    if (wv == null)
      return; 
    wv.refreshPerspectiveButton(needUpdatePerspectiveIDS);
  }
  
  public static void relocatePerspectiveBtn(String lastPerspIDS) {}
}
